Struct proc_mounts::SwapInfo
source · pub struct SwapInfo {
pub source: PathBuf,
pub kind: OsString,
pub size: usize,
pub used: usize,
pub priority: isize,
}Expand description
A swap entry, which defines an active swap.
Fields
source: PathBufThe path where the swap originates from.
kind: OsStringThe kind of swap, such as partition or file.
size: usizeThe size of the swap partition.
used: usizeWhether the swap is used or not.
priority: isizeThe priority of a swap, which indicates the order of usage.
Implementations